# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: system.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csystem.proto\x12\x07oi.papi\x1a\x1cgoogle/api/annotations.proto\"\r\n\x0bPingRequest\"#\n\x0cPingResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2a\n\tSystemApi\x12T\n\x08get_ping\x12\x14.oi.papi.PingRequest\x1a\x15.oi.papi.PingResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/systemapi/get_pingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'system_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SYSTEMAPI.methods_by_name['get_ping']._options = None
  _SYSTEMAPI.methods_by_name['get_ping']._serialized_options = b'\202\323\344\223\002\025\022\023/systemapi/get_ping'
  _PINGREQUEST._serialized_start=55
  _PINGREQUEST._serialized_end=68
  _PINGRESPONSE._serialized_start=70
  _PINGRESPONSE._serialized_end=105
  _SYSTEMAPI._serialized_start=107
  _SYSTEMAPI._serialized_end=204
# @@protoc_insertion_point(module_scope)
