# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64\x61ta_type.proto\x12\x07oi.papi\"k\n\x08\x44\x61taType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x61ta_source_ids\x18\x04 \x03(\t\x12\x13\n\x0bsensor_type\x18\x05 \x01(\t\"_\n\x15\x44\x61taTypeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x13\n\x0bsensor_type\x18\x04 \x01(\t\"S\n\x16\x44\x61taTypeCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12$\n\tdata_type\x18\x02 \x01(\x0b\x32\x11.oi.papi.DataType\"!\n\x12\x44\x61taTypeGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"Q\n\x13\x44\x61taTypeGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12%\n\ndata_types\x18\x02 \x03(\x0b\x32\x11.oi.papi.DataType\"*\n\x13\x44\x61taTypeListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"R\n\x14\x44\x61taTypeListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12%\n\ndata_types\x18\x02 \x03(\x0b\x32\x11.oi.papi.DataType2\xdf\x01\n\x0b\x44\x61taTypeAPI\x12I\n\x06\x63reate\x12\x1e.oi.papi.DataTypeCreateRequest\x1a\x1f.oi.papi.DataTypeCreateResponse\x12@\n\x03get\x12\x1b.oi.papi.DataTypeGetRequest\x1a\x1c.oi.papi.DataTypeGetResponse\x12\x43\n\x04list\x12\x1c.oi.papi.DataTypeListRequest\x1a\x1d.oi.papi.DataTypeListResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATATYPE._serialized_start=28
  _DATATYPE._serialized_end=135
  _DATATYPECREATEREQUEST._serialized_start=137
  _DATATYPECREATEREQUEST._serialized_end=232
  _DATATYPECREATERESPONSE._serialized_start=234
  _DATATYPECREATERESPONSE._serialized_end=317
  _DATATYPEGETREQUEST._serialized_start=319
  _DATATYPEGETREQUEST._serialized_end=352
  _DATATYPEGETRESPONSE._serialized_start=354
  _DATATYPEGETRESPONSE._serialized_end=435
  _DATATYPELISTREQUEST._serialized_start=437
  _DATATYPELISTREQUEST._serialized_end=479
  _DATATYPELISTRESPONSE._serialized_start=481
  _DATATYPELISTRESPONSE._serialized_end=563
  _DATATYPEAPI._serialized_start=566
  _DATATYPEAPI._serialized_end=789
# @@protoc_insertion_point(module_scope)
