# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: visualization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13visualization.proto\x12\x15oi.papi.visualization\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x05\n\rVisualization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x63omputation_id\x18\x02 \x01(\t\x12\x1d\n\x15result_observation_id\x18\x03 \x01(\t\x12\x37\n\x04type\x18\x04 \x01(\x0e\x32).oi.papi.visualization.Visualization.Type\x12\x39\n\x05state\x18\x05 \x01(\x0e\x32*.oi.papi.visualization.Visualization.State\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x0b\x61\x63\x63\x65ss_info\x18\x07 \x01(\x0b\x32/.oi.papi.visualization.Visualization.AccessInfo\x12.\n\ncreated_on\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1aP\n\nAccessInfo\x12\x14\n\x0curl_template\x18\x01 \x01(\t\x12,\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"A\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0c\n\x08STANDARD\x10\x01\x12\x0b\n\x07SPATIAL\x10\x02\x12\x0c\n\x08TEMPORAL\x10\x03\"\x7f\n\x05State\x12\x11\n\rUNKNOWN_STATE\x10\x00\x12\x07\n\x03NEW\x10\x01\x12\n\n\x06QUEUED\x10\x02\x12\x0e\n\nVALIDATING\x10\x03\x12\t\n\x05\x45MPTY\x10\x04\x12\x0c\n\x08UPLOADED\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\x12\x0c\n\x08\x44\x45LETING\x10\x07\x12\x0b\n\x07\x44\x45LETED\x10\x08\"9\n\x17VisualizationGetRequest\x12\x1e\n\x16result_observation_ids\x18\x01 \x03(\t\"m\n\x18VisualizationGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12<\n\x0evisualizations\x18\x02 \x03(\x0b\x32$.oi.papi.visualization.Visualization2z\n\x10VisualizationApi\x12\x66\n\x03get\x12..oi.papi.visualization.VisualizationGetRequest\x1a/.oi.papi.visualization.VisualizationGetResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'visualization_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VISUALIZATION._serialized_start=110
  _VISUALIZATION._serialized_end=795
  _VISUALIZATION_ACCESSINFO._serialized_start=519
  _VISUALIZATION_ACCESSINFO._serialized_end=599
  _VISUALIZATION_TYPE._serialized_start=601
  _VISUALIZATION_TYPE._serialized_end=666
  _VISUALIZATION_STATE._serialized_start=668
  _VISUALIZATION_STATE._serialized_end=795
  _VISUALIZATIONGETREQUEST._serialized_start=797
  _VISUALIZATIONGETREQUEST._serialized_end=854
  _VISUALIZATIONGETRESPONSE._serialized_start=856
  _VISUALIZATIONGETRESPONSE._serialized_end=965
  _VISUALIZATIONAPI._serialized_start=967
  _VISUALIZATIONAPI._serialized_end=1089
# @@protoc_insertion_point(module_scope)
